MCA
===

.. currentmodule:: xeofs.cross

.. autoclass:: MCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MCA.__init__
      ~MCA.components
      ~MCA.compute
      ~MCA.correlation_coefficients_X
      ~MCA.correlation_coefficients_Y
      ~MCA.covariance_fraction_CD95
      ~MCA.cross_correlation_coefficients
      ~MCA.deserialize
      ~MCA.fit
      ~MCA.fraction_variance_X_explained_by_X
      ~MCA.fraction_variance_Y_explained_by_X
      ~MCA.fraction_variance_Y_explained_by_Y
      ~MCA.get_params
      ~MCA.get_serialization_attrs
      ~MCA.heterogeneous_patterns
      ~MCA.homogeneous_patterns
      ~MCA.inverse_transform
      ~MCA.load
      ~MCA.predict
      ~MCA.save
      ~MCA.scores
      ~MCA.serialize
      ~MCA.squared_covariance_fraction
      ~MCA.transform
   
   

   
   
   